% This function derives the location-dependent contact matrix from the agents' and individuals' contact traces
%
% Input:
% contTrace is a cell containing M matrices where each matrix corresponds to the
% traces of one agent. Each matrix has three columns where the first column
% is the ID of the individual contacted by the agent, where the second column
% is the time of contact and where the third columns is the location where the contact
% occurred.
% NOTE: the IDs of discovered individuals in contTrace must be numbered
% from 1 to S.  The time of contacts must be between 0 and eventDuration. 
% The locations of contacts must be numbered between 1 and K.
% M is the number of agents and S is the number of discovered individuals.
%
% Output:
% contMat is an SxMxK matrix where element ijk is equal to the number of times
% that agent j contacts individual i in location k, for 1<=i<=S, 1<=j<=M,
% and 1<=k<=K.

function [contMat] = contMatCalc2(contTrace, M, S, K)

contMat = zeros(S, M, K);

% reformating the agents' traces
for agentIter = 1:M
 
    % iteration over each agent
    agentTrace = contTrace{agentIter, 1};
    for locIter = 1:size(agentTrace, 1)
        contMat(agentTrace(locIter, 1), agentIter, agentTrace(locIter, 3)) = contMat(agentTrace(locIter, 1), agentIter, agentTrace(locIter, 3)) + 1;
    end
 
end