% This function plots the evolution of the number of discovered individuals
% by agents and also by the aggregated traces of all agents. It also plots
% the total number of discovered individuals and the duration of stay for
% each agent.

%
% Input:
% contTrace is a cell containing M matrices where each matrix corresponds to
% the traces of one agent. Each matrix has two columns where the first column
% is the ID of the individual contacted by the agent and the second column
% is the time of contact. The IDs of individuals are numbered from 1 to S.
% M is the number of agents and eventDuration is the duration of the event
% (i.e., experiment) or observation window
% agentEntDepTimes is an Mx2 matrix where the first column is the arrival
% times of the agents to the event and the second column is the departure
% times of the agents from the event.

function displayTrace(contTrace, eventDuration, M, agentEntDepTimes)
%% first plotting the evolution of the number of discovered individuals
% by agents
figure;
hold on;
for agentIter = 1:M
    % considering one of the agents
    agentTrace = contTrace{agentIter, 1};
    % finding the position of the newly discovered individials by this
    % agent
    [~, j, ~] = unique(agentTrace(:, 1));
    indice = zeros(length(agentTrace(:, 1)), 1);
    indice(j) = 1;
    indice = cumsum(indice);
    % ploting the evolution for this agent
    plot(agentTrace(:, 2), indice, 'color', rand(1, 3), 'LineWidth', 2);
 
end
xlabel('Time')
title('Evolution of the number of discovered individuals by each agent')
xlim([0 eventDuration]);

%% second plotting the evolution of the number of discovered individuals
% by the aggregated trace of all the agents
aggAgentTrace = [];
for agentIter = 1:M
    agentTrace = contTrace{agentIter, 1};
    aggAgentTrace = [aggAgentTrace; agentTrace];
end

% sorting by time
[~, index] = sort(aggAgentTrace(:, 2));
aggAgentTrace = aggAgentTrace(index, :);

% finding the position of the newly discovered individials 
[~, j, ~] = unique(aggAgentTrace(:, 1));
indice = zeros(length(aggAgentTrace(:, 1)), 1);
indice(j) = 1;
indice = cumsum(indice);
figure, plot(aggAgentTrace(:, 2), indice, '--', 'LineWidth', 2);
xlabel('Time')
title('Evolution of the number of discovered individuals by all agents')
xlim([0 eventDuration]);

%% third plotting the total number of discovered individuals and the duration of stay for each agent
totDetTime = zeros(2, M); %buffer
for agentIter = 1:M
    % total numver of discovered individuals by this agent
    totDetTime(1, agentIter) = length(unique(contTrace{agentIter}(:, 1)));
    % duration of stay in the event for this agent
    totDetTime(2, agentIter) = agentEntDepTimes(agentIter, 2) - agentEntDepTimes(agentIter, 1);
end

% sorting based on the number of discovered individuals
[~, indice] = sort(totDetTime(1, :), 'descend');
totDetTime = totDetTime(:, indice);
% plotting bar plot
figure, bar(totDetTime');
xlabel('Agent number (sorted by # discovered individuals)');
legend('# discovered individuals', 'Duration of stay');
xlim([0.25 M + 0.75]);